@@ -6,13 +6,12 @@ import requests
 import sys
 from feagi_agent_freenove.Led import *
 from feagi_agent_freenove.PCA9685 import PCA9685
-from feagi_agent_freenove.configuration import  *
+from feagi_agent_freenove.configuration import *
 from picamera import PiCamera
 from datetime import datetime
 from collections import deque
 from picamera.array import PiRGBArray
 
-
 runtime_data = {
     "current_burst_id": 0,
     "feagi_state": None,
@@ -84,8 +83,8 @@ class Servo:
         self.PwmServo = PCA9685(0x40, debug=True)
         self.PwmServo.setPWMFreq(50)
         self.device_position = float()
-        self.servo_ranges = {0: [0, 180],
-                             1: [0, 180]}
+        self.servo_ranges = {0: [10, 160],
+                             1: [78, 160]}
 
     def setServoPwm(self, channel, angle, error=10):
         angle = float(angle)
@@ -110,16 +109,13 @@ class Servo:
         try:
             # Setting the initial position for the servo
             servo_0_initial_position = 90
-            self.device_position = servo_0_initial_position
-            self.move(0, self.device_position)
-            runtime_data['servo_status'][0] = self.device_position
+            runtime_data['servo_status'][0] = servo_0_initial_position
+            self.setServoPwm(str(0), runtime_data['servo_status'][0])
             print("Servo 0 was moved to its initial position")
 
             servo_1_initial_position = 90
-            self.device_position = servo_1_initial_position
-            self.move(1, self.device_position)
-            runtime_data['servo_status'][1] = self.device_position
-            print("Servo 1 was moved to its initial position")
+            runtime_data['servo_status'][1] = servo_1_initial_position
+            self.setServoPwm(str(1), runtime_data['servo_status'][0])
         except Exception as e:
             print("Error while setting initial position for the servo:", e)
 
@@ -137,8 +133,8 @@ class Servo:
                 runtime_data['servo_status'][device_index] = device_index
 
             device_current_position = runtime_data['servo_status'][device_index]
-            self.device_position = float((power * network_settings['feagi_burst_speed'] / 0.5) +
-                                         device_current_position)
+            self.device_position = float((power * feagi_settings['feagi_burst_speed'] /
+                                          capabilities["servo"]["power_amount"]) + device_current_position)
 
             self.device_position = self.keep_boundaries(device_id=device_index,
                                                         current_position=self.device_position)
@@ -414,20 +410,36 @@ def main():
 
     # # # FEAGI registration # # #
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
+    print("Connecting to FEAGI resources...")
+
     feagi_host, api_port, app_data_port = FEAGI.feagi_setting_for_registration(feagi_settings, agent_settings)
+
+    print(feagi_host, api_port, app_data_port)
+
+    # address = 'tcp://' + network_settings['feagi_host'] + ':' + network_settings['feagi_opu_port']
+
+    api_address = 'http://' + feagi_host + ':' + api_port
+
+    stimulation_period_endpoint = FEAGI.feagi_api_burst_engine()
+    burst_counter_endpoint = FEAGI.feagi_api_burst_counter()
+    print("^ ^ ^")
     runtime_data["feagi_state"] = FEAGI.feagi_registration(feagi_host=feagi_host,
                                                            api_port=api_port, agent_settings=agent_settings,
                                                            capabilities=capabilities)
+
+    print("** **", runtime_data["feagi_state"])
+    feagi_settings['feagi_burst_speed'] = float(runtime_data["feagi_state"]['burst_duration'])
+
+    # todo: to obtain this info directly from FEAGI as part of registration
+    # ipu_channel_address = FEAGI.feagi_inbound(agent_settings["agent_data_port"])
     ipu_channel_address = FEAGI.feagi_outbound(feagi_settings['feagi_host'],
                                                agent_settings["agent_data_port"])
+    print("IPU_channel_address=", ipu_channel_address)
     opu_channel_address = FEAGI.feagi_outbound(feagi_settings['feagi_host'],
                                                runtime_data["feagi_state"]['feagi_opu_port'])
+
     feagi_ipu_channel = FEAGI.pub_initializer(ipu_channel_address, bind=False)
     feagi_opu_channel = FEAGI.sub_initializer(opu_address=opu_channel_address)
-    api_address = 'http://' + feagi_host + ':' + api_port
-    stimulation_period_endpoint = FEAGI.feagi_api_burst_engine()
-    burst_counter_endpoint = FEAGI.feagi_api_burst_counter()
-    feagi_settings['feagi_burst_speed'] = float(runtime_data["feagi_state"]['burst_duration'])
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
 
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - #
@@ -460,6 +472,7 @@ def main():
     camera.framerate = 32
     rawCapture = PiRGBArray(camera, size=(640, 480))
     motor.stop()
+    servo.set_default_position()
     while True:
         try:
             for frame in camera.capture_continuous(rawCapture, format="bgr", use_video_port=True):
@@ -593,5 +606,3 @@ def main():
 
 if __name__ == '__main__':
     main()
-
-
