@@ -21,11 +21,13 @@ sleep 5
 echo "Installing..."
 sudo apt-get install -y python3-dev python3-rpi.gpio
 sudo apt-get install -y python3-smbus
+sudo apt-get install -y libatlas-base-dev
 sudo apt install -y python3-pip
 sudo pip3 install zmq
 sudo pip3 install feagi-agent
 sudo pip3 install rpi_ws281x
-sudo apt install -y libatlas-base-dev
+sudo pip3 install opencv-python==4.6.0.66
+sudo pip3 install -U numpy
 sudo groupadd gpio
 sudo usermod -aG gpio "${USER}"
-echo "Setup is complete!"
+echo "Setup is complete!"
\ No newline at end of file
